==> blackened-1.7.1.tar.gz: blackened-1.7.1/include/toast.h <==
#ifndef _TOAST_H_
#define _TOAST_H_

/* Modifications by Timothy L. Jensen aka Toast. */

#define	TACTION_NONE		0
#define	TACTION_FINDU		1
#define TACTION_FINDK		2
#define	TACTION_BANCOUNT	3
#define TACTION_CSTAT		4
#define TACTION_FINDD		5
#define TACTION_WHOKILL		6

#define FIND_NONE	0
#define FIND_COUNT	1
#define FIND_REMOVE	2

typedef struct SpingStuffStru {
	char *server;
	long start, ustart;
	struct SpingStuffStru *next;
} SpingStuff;

extern	int	page_updown_key;

extern	int	toast_action;

extern	int	in_whois;
extern	int	lusers_user_cnt;
extern	int	bc_count;
extern	char	*bc_chname;

char	*TimeStamp();
char	*MakeTimeStamp(long);
void	channel_created(char *from, char **ArgList);
void	channel_topictime(char *from, char **ArgList);
int	Do_Not_Log(char *from);
void	nolog();
void	doleave();
void	dowho();
void	dowii();
void	dotopic();
void	domode();
void	dokline();
void	unkline();
void	vercmd();
void	auto_msg();
void	do_new_window();
void	do_kill_window();
void	do_list_windows();
void	do_grow_window();
void	do_shrink_window();
void	do_hide_window();
void	do_opervision();
void	do_pageup();
void	do_pagedown();
void	handle_findu();
void	findu();
void	handle_findk();
void	findk();
void	bancount();
void	handle_cstat();
void	cstat();
void	userhost_notify();
int	handle_sping();
void	handle_sping_nosuchserver();
void	sping();
void	show_banner();
void	umode();
void	handle_whokill(char*, char*, char*, char*);
void	add_to_away(char*, char*);
int	seen_away_msg(char*, char*);
char	*function_randread(char *);
void	invitecmd();
char	*SmallTS(const time_t*);
void	awaylistcmd();
void	set_oops(char *, char *, char*);
void	oopscmd();
void	userhost_finger();
void	change_server_tempbans(int, int);
void	insert_ban(char *, char *, int);
void	BanTimer();
void	handle_findd();
void	findd();
char	*filterlog(char *);
void	chat_cmd();
void	rchat_cmd();
void	show_tempbans();
void	dovoice();
void	dodevoice();
void	massvoice();
void	massdevoice();

#endif	/* _TOAST_H_ */

==> blackened_1.8.0.orig.tar.gz: blackened-1.8.0.orig/include/toast.h <==
#ifndef _TOAST_H_
#define _TOAST_H_

/* Modifications by Timothy L. Jensen aka Toast. */

#define	TACTION_NONE		0
#define	TACTION_FINDU		1
#define TACTION_FINDK		2
#define	TACTION_BANCOUNT	3
#define TACTION_CSTAT		4
#define TACTION_FINDD		5
#define TACTION_WHOKILL		6

#define FIND_NONE	0
#define FIND_COUNT	1
#define FIND_REMOVE	2

typedef struct SpingStuffStru {
	char *server;
	long start, ustart;
	struct SpingStuffStru *next;
} SpingStuff;

extern	int	page_updown_key;

extern	int	toast_action;

extern	int	in_whois;
extern	int	bc_count;
extern	char	*bc_chname;

extern	int	setting_nolog;

char	*TimeStamp();
char	*MakeTimeStamp(long);
void	channel_created(char *from, char **ArgList);
void	channel_topictime(char *from, char **ArgList);
int	Do_Not_Log(char *from);
void	nolog();
void	set_nolog();
void	doleave();
void	dowho();
void	dowii();
void	dotopic();
void	domode();
void	dokline();
void	unkline();
void	vercmd();
void	auto_msg();
void	remnick(char *);
void	do_new_window();
void	do_kill_window();
void	do_list_windows();
void	do_grow_window();
void	do_shrink_window();
void	do_hide_window();
void	do_opervision();
void	do_pageup();
void	do_pagedown();
void	handle_findu();
void	findu();
void	handle_findk();
void	findk();
void	bancount();
void	handle_cstat();
void	cstat();
void	userhost_notify();
int	handle_sping();
void	handle_sping_nosuchserver();
void	sping();
void	show_banner();
void	umode();
void	handle_whokill(char*, char*, char*, char*);
void	add_to_away(char*, char*);
int	seen_away_msg(char*, char*);
char	*function_randread(char *);
void	invitecmd();
char	*SmallTS(const time_t*);
void	awaylistcmd();
void	set_oops(char *, char *, char*);
void	oopscmd();
void	userhost_finger();
void	change_server_tempbans(int, int);
void	insert_ban(char *, char *, int);
void	BanTimer();
void	handle_findd();
void	findd();
char	*filterlog(char *);
void	chat_cmd();
void	rchat_cmd();
void	show_tempbans();
void	dovoice();
void	dodevoice();
void	massvoice();
void	massdevoice();
void	toasttest();

#endif	/* _TOAST_H_ */
